@@ -81,11 +81,20 @@ sub new {
     } else {
         $self->{opts} = NBI::Opts->new($DEFAULT_QUEUE);
     }
+
+    $self->{script_path} = undef;
     return $self;
  
 }
 
 
+sub script_path : lvalue {
+    # Update script_path
+    my ($self, $new_val) = @_;
+    $self->{script_path} = $new_val if (defined $new_val);
+    return $self->{script_path};
+}
+
 sub name : lvalue {
     # Update name
     my ($self, $new_val) = @_;
@@ -105,21 +114,56 @@ sub jobid : lvalue {
 
 sub outputfile : lvalue {
     # Update name
-    my ($self, $new_val) = @_;
-    $self->{output_file} = $new_val if (defined $new_val);
+    my ($self, $parameter) = @_;
+
+    my $interpolate = 0;
+    if (defined $parameter) {
+        if ($parameter eq '-interpolate') {
+            $interpolate = 1;
+        } else {
+            $self->{output_file} = $parameter;
+        }
+    }
+
+    # Create a default output_file if not defined
     if (not defined $self->{output_file}) {
         $self->{output_file} = catfile( $self->opts->tmpdir , $self->name . ".%j.out");
+    }
+    
+    if ($interpolate) {
+        my $jobid = $self->jobid;
+        my $output_file = $self->{output_file};
+        $output_file =~ s/%j/$jobid/g;
+        return $output_file;
     } else {
         return $self->{output_file};
     }
+    
 }
 
 sub errorfile : lvalue {
-    # Update name
-    my ($self, $new_val) = @_;
-    $self->{error_file} = $new_val if (defined $new_val);
+   # Update name
+    my ($self, $parameter) = @_;
+
+    my $interpolate = 0;
+    if (defined $parameter) {
+        if ($parameter eq '-interpolate') {
+            $interpolate = 1;
+        } else {
+            $self->{error_file} = $parameter;
+        }
+    }
+
+    # Create a default error_file if not defined
     if (not defined $self->{error_file}) {
-        $self->{error_file} =  catfile($self->opts->tmpdir, $self->name . ".%j.err");
+        $self->{error_file} = catfile( $self->opts->tmpdir , $self->name . ".%j.out");
+    }
+    
+    if ($interpolate) {
+        my $jobid = $self->jobid;
+        my $error_file = $self->{error_file};
+        $error_file =~ s/%j/$jobid/g;
+        return $error_file;
     } else {
         return $self->{error_file};
     }
@@ -221,6 +265,17 @@ sub run {
 
     # Create the script file
     my $script_file = catfile($self->opts->tmpdir, $self->name . ".sh");
+
+    # change suffix from .sh to .INT.sh if the file exists already
+    if (-e $script_file) {
+        my $i = 1;
+        while (-e $script_file) {
+            my $string_int = sprintf("%05d", $i);
+            $script_file = catfile($self->opts->tmpdir, $self->name . "." . $string_int . ".sh");
+            $i++;
+        }
+    }
+    $self->{"script_path"} = $script_file;
     open(my $fh, ">", $script_file) or confess "ERROR NBI::Job: Cannot open file $script_file for writing\n";
     print $fh $script;
     close($fh);
@@ -238,7 +293,7 @@ sub run {
         # Job submitted
         my $job_id = $1;
         # Update the job id
-        $self->{job_id} = $job_id;
+        $self->jobid = $job_id;
         return $job_id;
     } else {
         # Job not submitted
@@ -248,6 +303,21 @@ sub run {
 }
 
 
+sub view {
+    # Return a string representation of the object
+    my $self = shift @_;
+    my $str = " --- NBI::Job object ---\n";
+    $str .= " name:       " . $self->name . "\n";
+    $str .= " commands:   \n\t" . join("\n\t", @{$self->commands}) . "\n";
+    $str .= " jobid:      " . $self->jobid . "\n";    
+    $str .= " script:     " . $self->script_path . "\n";
+    $str .= " output file:" . $self->outputfile('-interpolate') . "\n";
+    $str .= " error file: " . $self->errorfile('-interpolate') . "\n";
+    $str .= " ---------------------------\n";
+ 
+    return $str;
+}
+
 sub _has_command {
     my $command = shift;
     my $is_available = 0;
@@ -282,7 +352,7 @@ NBI::Job - A class for representing a job for NBI::Slurm
 
 =head1 VERSION
 
-version 0.7.1
+version 0.8.0
 
 =head1 SYNOPSIS
 
@@ -375,6 +445,11 @@ Accessor method for the error file path.
 
 This method allows you to get or set the path of the error file generated by the job. If called with an argument, it sets the error file path to the specified value. If called without an argument, it returns the current error file path.
 
+=head2 script_path
+
+Accessor method for the actual script path. This is the path of the script file generated by the job.
+invoking C<run()> will generate a script path if it was not set.
+
 =head2 append_command
 
 Append a command to the job.
@@ -448,6 +523,12 @@ Submit the job to SLURM.
 This method submits the job to SLURM for execution. 
 It generates the sbatch script, writes it to a file, and uses the "sbatch" command to submit the job. If the submission is successful, it returns the job ID assigned by SLURM. Otherwise, it throws an exception.
 
+=head2 view
+
+Return a string representation of the object.
+
+  my $str = $job->view;
+
 =head1 AUTHOR
 
 Andrea Telatin <proch@cpan.org>
